==> aws-android-sdk-iot-2.15.0-sources.jar: com/amazonaws/services/iot/model/transform/DescribeSecurityProfileResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.iot.model.transform;

import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response DescribeSecurityProfileResult
 */
public class DescribeSecurityProfileResultJsonUnmarshaller implements
        Unmarshaller<DescribeSecurityProfileResult, JsonUnmarshallerContext> {

    public DescribeSecurityProfileResult unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        DescribeSecurityProfileResult describeSecurityProfileResult = new DescribeSecurityProfileResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("securityProfileName")) {
                describeSecurityProfileResult.setSecurityProfileName(StringJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("securityProfileArn")) {
                describeSecurityProfileResult.setSecurityProfileArn(StringJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("securityProfileDescription")) {
                describeSecurityProfileResult.setSecurityProfileDescription(StringJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("behaviors")) {
                describeSecurityProfileResult.setBehaviors(new ListUnmarshaller<Behavior>(
                        BehaviorJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("alertTargets")) {
                describeSecurityProfileResult.setAlertTargets(new MapUnmarshaller<AlertTarget>(
                        AlertTargetJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("additionalMetricsToRetain")) {
                describeSecurityProfileResult
                        .setAdditionalMetricsToRetain(new ListUnmarshaller<String>(
                                StringJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("version")) {
                describeSecurityProfileResult.setVersion(LongJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("creationDate")) {
                describeSecurityProfileResult.setCreationDate(DateJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("lastModifiedDate")) {
                describeSecurityProfileResult.setLastModifiedDate(DateJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return describeSecurityProfileResult;
    }

    private static DescribeSecurityProfileResultJsonUnmarshaller instance;

    public static DescribeSecurityProfileResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeSecurityProfileResultJsonUnmarshaller();
        return instance;
    }
}

==> aws-android-sdk-iot-2.22.6-sources.jar: com/amazonaws/services/iot/model/transform/DescribeSecurityProfileResultJsonUnmarshaller.java <==
/*
 * Copyright 2010-2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.iot.model.transform;

import com.amazonaws.services.iot.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for response DescribeSecurityProfileResult
 */
public class DescribeSecurityProfileResultJsonUnmarshaller implements
        Unmarshaller<DescribeSecurityProfileResult, JsonUnmarshallerContext> {

    public DescribeSecurityProfileResult unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        DescribeSecurityProfileResult describeSecurityProfileResult = new DescribeSecurityProfileResult();

        AwsJsonReader reader = context.getReader();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("securityProfileName")) {
                describeSecurityProfileResult.setSecurityProfileName(StringJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("securityProfileArn")) {
                describeSecurityProfileResult.setSecurityProfileArn(StringJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("securityProfileDescription")) {
                describeSecurityProfileResult.setSecurityProfileDescription(StringJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("behaviors")) {
                describeSecurityProfileResult.setBehaviors(new ListUnmarshaller<Behavior>(
                        BehaviorJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("alertTargets")) {
                describeSecurityProfileResult.setAlertTargets(new MapUnmarshaller<AlertTarget>(
                        AlertTargetJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("additionalMetricsToRetain")) {
                describeSecurityProfileResult
                        .setAdditionalMetricsToRetain(new ListUnmarshaller<String>(
                                StringJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("additionalMetricsToRetainV2")) {
                describeSecurityProfileResult
                        .setAdditionalMetricsToRetainV2(new ListUnmarshaller<MetricToRetain>(
                                MetricToRetainJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("version")) {
                describeSecurityProfileResult.setVersion(LongJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("creationDate")) {
                describeSecurityProfileResult.setCreationDate(DateJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("lastModifiedDate")) {
                describeSecurityProfileResult.setLastModifiedDate(DateJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();

        return describeSecurityProfileResult;
    }

    private static DescribeSecurityProfileResultJsonUnmarshaller instance;

    public static DescribeSecurityProfileResultJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new DescribeSecurityProfileResultJsonUnmarshaller();
        return instance;
    }
}
